# core-image-tester
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import argparse
import configparser
import logging
import os

from uservice_utils.logging import configure_service_logging

from core_image_tester import constants
from core_image_tester.queue import (
    CoreImageTesterQueueMonitor,
    create_connection_from_config,
    CoreImageTestResultPublisher,
)
from core_image_tester.worker import CoreImageTesterWorker


def read_config():
    parser = argparse.ArgumentParser(description='Core image tester.')
    parser.add_argument(
        '-c',
        '--conf',
        default='core-service.conf',
        help='Configuration file path'
    )
    args = parser.parse_args()

    # Load configuration options.
    config = configparser.ConfigParser()
    config.read(args.conf)
    return config


def main():
    config = read_config()
    log_path = os.path.abspath(
        os.path.join(__file__, '../../logs/core-image-tester.log'))
    configure_service_logging(
        log_path,
        config['logstash'] if 'logstash' in config else None
    )
    logger = logging.getLogger(__name__)
    logger.info('Started!', extra=constants.LOGGING_EXTRA)

    kombu_connection = create_connection_from_config(config)
    try:
        with kombu_connection:
            worker = CoreImageTesterWorker(
                config,
                CoreImageTestResultPublisher(kombu_connection)
            )
            queue_monitor = CoreImageTesterQueueMonitor(
                kombu_connection, worker)
            queue_monitor.run()
    except KeyboardInterrupt:
        print("Bye!")
